pub mod model;

// https://bitwarden.com/help/vault-management-api/

pub fn sync() -> Result<model::response::Sync, Box<dyn std::error::Error>> {
    let client = reqwest::blocking::Client::new();
    let response = client.post("http://localhost:8087/sync")
        .send()?
        .json::<model::response::Sync>()?;

    if response.success {
        Ok(response)
    } else {
        Err("success != true in JSON response".into())
    }
}

pub fn status() -> Result<model::response::Status, Box<dyn std::error::Error>> {
    let client = reqwest::blocking::Client::new();
    let response = client.get("http://localhost:8087/status")
        .send()?
        .json::<model::response::Status>()?;

    if response.success {
        Ok(response)
    } else {
        Err("success != true in JSON response".into())
    }
}

pub fn list_object_items() -> Result<model::response::ListObjectItems, Box<dyn std::error::Error>> {
    let client = reqwest::blocking::Client::new();
    let response = client.get("http://localhost:8087/list/object/items")
    // let response = client.get("http://localhost:8087/list/object/items?folderId=50d2f507-8f0a-416c-80a4-afb100a77700")
        .send()?;

    // dbg!(response.text());
    // panic!();

    let json = response.json::<model::response::ListObjectItems>()?;
    if json.success {
        Ok(json)
    } else {
        Err("success != true in JSON response".into())
    }
}

pub fn list_object_collections() -> Result<model::response::ListObjectCollections, Box<dyn std::error::Error>> {
    let client = reqwest::blocking::Client::new();
    let response = client.get("http://localhost:8087/list/object/collections")
        .send()?
        .json::<model::response::ListObjectCollections>()?;

    if response.success {
        Ok(response)
    } else {
        Err("success != true in JSON response".into())
    }
}

pub fn list_object_folders() -> Result<model::response::ListObjectFolders, Box<dyn std::error::Error>> {
    let client = reqwest::blocking::Client::new();
    let response = client.get("http://localhost:8087/list/object/folders")
        .send()?
        .json::<model::response::ListObjectFolders>()?;

    if response.success {
        Ok(response)
    } else {
        Err("success != true in JSON response".into())
    }
}

pub fn object_item(id: &String) -> Result<model::response::ObjectItem, Box<dyn std::error::Error>> {
    let client = reqwest::blocking::Client::new();
    let response = client.get(format!("http://localhost:8087/object/item/{}", id))
        .send()?
        .json::<model::response::ObjectItem>()?;

    if response.success {
        Ok(response)
    } else {
        Err("success != true in JSON response".into())
    }
}
